# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class CreateDBInstanceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'charge_info': 'ChargeInfoForCreateDBInstanceInput',
        'db_engine_version': 'str',
        'db_param_group_id': 'str',
        'db_time_zone': 'str',
        'instance_name': 'str',
        'instance_tags': 'list[InstanceTagForCreateDBInstanceInput]',
        'lower_case_table_names': 'str',
        'node_info': 'list[NodeInfoForCreateDBInstanceInput]',
        'number': 'int',
        'project_name': 'str',
        'storage_space': 'int',
        'storage_type': 'str',
        'subnet_id': 'str',
        'super_account_name': 'str',
        'super_account_password': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'charge_info': 'ChargeInfo',
        'db_engine_version': 'DBEngineVersion',
        'db_param_group_id': 'DBParamGroupId',
        'db_time_zone': 'DBTimeZone',
        'instance_name': 'InstanceName',
        'instance_tags': 'InstanceTags',
        'lower_case_table_names': 'LowerCaseTableNames',
        'node_info': 'NodeInfo',
        'number': 'Number',
        'project_name': 'ProjectName',
        'storage_space': 'StorageSpace',
        'storage_type': 'StorageType',
        'subnet_id': 'SubnetId',
        'super_account_name': 'SuperAccountName',
        'super_account_password': 'SuperAccountPassword',
        'vpc_id': 'VpcId'
    }

    def __init__(self, charge_info=None, db_engine_version=None, db_param_group_id=None, db_time_zone=None, instance_name=None, instance_tags=None, lower_case_table_names=None, node_info=None, number=None, project_name=None, storage_space=None, storage_type=None, subnet_id=None, super_account_name=None, super_account_password=None, vpc_id=None, _configuration=None):  # noqa: E501
        """CreateDBInstanceRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._charge_info = None
        self._db_engine_version = None
        self._db_param_group_id = None
        self._db_time_zone = None
        self._instance_name = None
        self._instance_tags = None
        self._lower_case_table_names = None
        self._node_info = None
        self._number = None
        self._project_name = None
        self._storage_space = None
        self._storage_type = None
        self._subnet_id = None
        self._super_account_name = None
        self._super_account_password = None
        self._vpc_id = None
        self.discriminator = None

        if charge_info is not None:
            self.charge_info = charge_info
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if db_param_group_id is not None:
            self.db_param_group_id = db_param_group_id
        if db_time_zone is not None:
            self.db_time_zone = db_time_zone
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_tags is not None:
            self.instance_tags = instance_tags
        if lower_case_table_names is not None:
            self.lower_case_table_names = lower_case_table_names
        if node_info is not None:
            self.node_info = node_info
        if number is not None:
            self.number = number
        if project_name is not None:
            self.project_name = project_name
        if storage_space is not None:
            self.storage_space = storage_space
        if storage_type is not None:
            self.storage_type = storage_type
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if super_account_name is not None:
            self.super_account_name = super_account_name
        if super_account_password is not None:
            self.super_account_password = super_account_password
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def charge_info(self):
        """Gets the charge_info of this CreateDBInstanceRequest.  # noqa: E501


        :return: The charge_info of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: ChargeInfoForCreateDBInstanceInput
        """
        return self._charge_info

    @charge_info.setter
    def charge_info(self, charge_info):
        """Sets the charge_info of this CreateDBInstanceRequest.


        :param charge_info: The charge_info of this CreateDBInstanceRequest.  # noqa: E501
        :type: ChargeInfoForCreateDBInstanceInput
        """

        self._charge_info = charge_info

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this CreateDBInstanceRequest.


        :param db_engine_version: The db_engine_version of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._db_engine_version = db_engine_version

    @property
    def db_param_group_id(self):
        """Gets the db_param_group_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_param_group_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_param_group_id

    @db_param_group_id.setter
    def db_param_group_id(self, db_param_group_id):
        """Sets the db_param_group_id of this CreateDBInstanceRequest.


        :param db_param_group_id: The db_param_group_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._db_param_group_id = db_param_group_id

    @property
    def db_time_zone(self):
        """Gets the db_time_zone of this CreateDBInstanceRequest.  # noqa: E501


        :return: The db_time_zone of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._db_time_zone

    @db_time_zone.setter
    def db_time_zone(self, db_time_zone):
        """Sets the db_time_zone of this CreateDBInstanceRequest.


        :param db_time_zone: The db_time_zone of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._db_time_zone = db_time_zone

    @property
    def instance_name(self):
        """Gets the instance_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this CreateDBInstanceRequest.


        :param instance_name: The instance_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_tags(self):
        """Gets the instance_tags of this CreateDBInstanceRequest.  # noqa: E501


        :return: The instance_tags of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: list[InstanceTagForCreateDBInstanceInput]
        """
        return self._instance_tags

    @instance_tags.setter
    def instance_tags(self, instance_tags):
        """Sets the instance_tags of this CreateDBInstanceRequest.


        :param instance_tags: The instance_tags of this CreateDBInstanceRequest.  # noqa: E501
        :type: list[InstanceTagForCreateDBInstanceInput]
        """

        self._instance_tags = instance_tags

    @property
    def lower_case_table_names(self):
        """Gets the lower_case_table_names of this CreateDBInstanceRequest.  # noqa: E501


        :return: The lower_case_table_names of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._lower_case_table_names

    @lower_case_table_names.setter
    def lower_case_table_names(self, lower_case_table_names):
        """Sets the lower_case_table_names of this CreateDBInstanceRequest.


        :param lower_case_table_names: The lower_case_table_names of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._lower_case_table_names = lower_case_table_names

    @property
    def node_info(self):
        """Gets the node_info of this CreateDBInstanceRequest.  # noqa: E501


        :return: The node_info of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: list[NodeInfoForCreateDBInstanceInput]
        """
        return self._node_info

    @node_info.setter
    def node_info(self, node_info):
        """Sets the node_info of this CreateDBInstanceRequest.


        :param node_info: The node_info of this CreateDBInstanceRequest.  # noqa: E501
        :type: list[NodeInfoForCreateDBInstanceInput]
        """

        self._node_info = node_info

    @property
    def number(self):
        """Gets the number of this CreateDBInstanceRequest.  # noqa: E501


        :return: The number of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this CreateDBInstanceRequest.


        :param number: The number of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def project_name(self):
        """Gets the project_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this CreateDBInstanceRequest.


        :param project_name: The project_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def storage_space(self):
        """Gets the storage_space of this CreateDBInstanceRequest.  # noqa: E501


        :return: The storage_space of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: int
        """
        return self._storage_space

    @storage_space.setter
    def storage_space(self, storage_space):
        """Sets the storage_space of this CreateDBInstanceRequest.


        :param storage_space: The storage_space of this CreateDBInstanceRequest.  # noqa: E501
        :type: int
        """

        self._storage_space = storage_space

    @property
    def storage_type(self):
        """Gets the storage_type of this CreateDBInstanceRequest.  # noqa: E501


        :return: The storage_type of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this CreateDBInstanceRequest.


        :param storage_type: The storage_type of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._storage_type = storage_type

    @property
    def subnet_id(self):
        """Gets the subnet_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this CreateDBInstanceRequest.


        :param subnet_id: The subnet_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def super_account_name(self):
        """Gets the super_account_name of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_name

    @super_account_name.setter
    def super_account_name(self, super_account_name):
        """Sets the super_account_name of this CreateDBInstanceRequest.


        :param super_account_name: The super_account_name of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                super_account_name is not None and len(super_account_name) > 16):
            raise ValueError("Invalid value for `super_account_name`, length must be less than or equal to `16`")  # noqa: E501
        if (self._configuration.client_side_validation and
                super_account_name is not None and len(super_account_name) < 2):
            raise ValueError("Invalid value for `super_account_name`, length must be greater than or equal to `2`")  # noqa: E501

        self._super_account_name = super_account_name

    @property
    def super_account_password(self):
        """Gets the super_account_password of this CreateDBInstanceRequest.  # noqa: E501


        :return: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._super_account_password

    @super_account_password.setter
    def super_account_password(self, super_account_password):
        """Sets the super_account_password of this CreateDBInstanceRequest.


        :param super_account_password: The super_account_password of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                super_account_password is not None and len(super_account_password) > 32):
            raise ValueError("Invalid value for `super_account_password`, length must be less than or equal to `32`")  # noqa: E501
        if (self._configuration.client_side_validation and
                super_account_password is not None and len(super_account_password) < 8):
            raise ValueError("Invalid value for `super_account_password`, length must be greater than or equal to `8`")  # noqa: E501

        self._super_account_password = super_account_password

    @property
    def vpc_id(self):
        """Gets the vpc_id of this CreateDBInstanceRequest.  # noqa: E501


        :return: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this CreateDBInstanceRequest.


        :param vpc_id: The vpc_id of this CreateDBInstanceRequest.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDBInstanceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDBInstanceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdkautoscaling.api.auto_scaling_api import AUTOSCALINGApi

# import models into sdk package
from volcenginesdkautoscaling.models.alarm_policy_condition_for_create_scaling_policy_input import AlarmPolicyConditionForCreateScalingPolicyInput
from volcenginesdkautoscaling.models.alarm_policy_condition_for_modify_scaling_policy_input import AlarmPolicyConditionForModifyScalingPolicyInput
from volcenginesdkautoscaling.models.alarm_policy_for_create_scaling_policy_input import AlarmPolicyForCreateScalingPolicyInput
from volcenginesdkautoscaling.models.alarm_policy_for_describe_scaling_policies_output import AlarmPolicyForDescribeScalingPoliciesOutput
from volcenginesdkautoscaling.models.alarm_policy_for_modify_scaling_policy_input import AlarmPolicyForModifyScalingPolicyInput
from volcenginesdkautoscaling.models.attach_db_instances_request import AttachDBInstancesRequest
from volcenginesdkautoscaling.models.attach_db_instances_response import AttachDBInstancesResponse
from volcenginesdkautoscaling.models.attach_instances_request import AttachInstancesRequest
from volcenginesdkautoscaling.models.attach_instances_response import AttachInstancesResponse
from volcenginesdkautoscaling.models.attach_server_groups_request import AttachServerGroupsRequest
from volcenginesdkautoscaling.models.attach_server_groups_response import AttachServerGroupsResponse
from volcenginesdkautoscaling.models.complete_lifecycle_activity_request import CompleteLifecycleActivityRequest
from volcenginesdkautoscaling.models.complete_lifecycle_activity_response import CompleteLifecycleActivityResponse
from volcenginesdkautoscaling.models.condition_for_describe_scaling_policies_output import ConditionForDescribeScalingPoliciesOutput
from volcenginesdkautoscaling.models.create_lifecycle_hook_request import CreateLifecycleHookRequest
from volcenginesdkautoscaling.models.create_lifecycle_hook_response import CreateLifecycleHookResponse
from volcenginesdkautoscaling.models.create_scaling_configuration_request import CreateScalingConfigurationRequest
from volcenginesdkautoscaling.models.create_scaling_configuration_response import CreateScalingConfigurationResponse
from volcenginesdkautoscaling.models.create_scaling_group_request import CreateScalingGroupRequest
from volcenginesdkautoscaling.models.create_scaling_group_response import CreateScalingGroupResponse
from volcenginesdkautoscaling.models.create_scaling_policy_request import CreateScalingPolicyRequest
from volcenginesdkautoscaling.models.create_scaling_policy_response import CreateScalingPolicyResponse
from volcenginesdkautoscaling.models.delete_lifecycle_hook_request import DeleteLifecycleHookRequest
from volcenginesdkautoscaling.models.delete_lifecycle_hook_response import DeleteLifecycleHookResponse
from volcenginesdkautoscaling.models.delete_scaling_configuration_request import DeleteScalingConfigurationRequest
from volcenginesdkautoscaling.models.delete_scaling_configuration_response import DeleteScalingConfigurationResponse
from volcenginesdkautoscaling.models.delete_scaling_group_request import DeleteScalingGroupRequest
from volcenginesdkautoscaling.models.delete_scaling_group_response import DeleteScalingGroupResponse
from volcenginesdkautoscaling.models.delete_scaling_policy_request import DeleteScalingPolicyRequest
from volcenginesdkautoscaling.models.delete_scaling_policy_response import DeleteScalingPolicyResponse
from volcenginesdkautoscaling.models.describe_lifecycle_activities_request import DescribeLifecycleActivitiesRequest
from volcenginesdkautoscaling.models.describe_lifecycle_activities_response import DescribeLifecycleActivitiesResponse
from volcenginesdkautoscaling.models.describe_lifecycle_hooks_request import DescribeLifecycleHooksRequest
from volcenginesdkautoscaling.models.describe_lifecycle_hooks_response import DescribeLifecycleHooksResponse
from volcenginesdkautoscaling.models.describe_scaling_activities_request import DescribeScalingActivitiesRequest
from volcenginesdkautoscaling.models.describe_scaling_activities_response import DescribeScalingActivitiesResponse
from volcenginesdkautoscaling.models.describe_scaling_configurations_request import DescribeScalingConfigurationsRequest
from volcenginesdkautoscaling.models.describe_scaling_configurations_response import DescribeScalingConfigurationsResponse
from volcenginesdkautoscaling.models.describe_scaling_groups_request import DescribeScalingGroupsRequest
from volcenginesdkautoscaling.models.describe_scaling_groups_response import DescribeScalingGroupsResponse
from volcenginesdkautoscaling.models.describe_scaling_instances_request import DescribeScalingInstancesRequest
from volcenginesdkautoscaling.models.describe_scaling_instances_response import DescribeScalingInstancesResponse
from volcenginesdkautoscaling.models.describe_scaling_policies_request import DescribeScalingPoliciesRequest
from volcenginesdkautoscaling.models.describe_scaling_policies_response import DescribeScalingPoliciesResponse
from volcenginesdkautoscaling.models.detach_db_instances_request import DetachDBInstancesRequest
from volcenginesdkautoscaling.models.detach_db_instances_response import DetachDBInstancesResponse
from volcenginesdkautoscaling.models.detach_instances_request import DetachInstancesRequest
from volcenginesdkautoscaling.models.detach_instances_response import DetachInstancesResponse
from volcenginesdkautoscaling.models.detach_server_groups_request import DetachServerGroupsRequest
from volcenginesdkautoscaling.models.detach_server_groups_response import DetachServerGroupsResponse
from volcenginesdkautoscaling.models.disable_scaling_group_request import DisableScalingGroupRequest
from volcenginesdkautoscaling.models.disable_scaling_group_response import DisableScalingGroupResponse
from volcenginesdkautoscaling.models.disable_scaling_policy_request import DisableScalingPolicyRequest
from volcenginesdkautoscaling.models.disable_scaling_policy_response import DisableScalingPolicyResponse
from volcenginesdkautoscaling.models.eip_for_create_scaling_configuration_input import EipForCreateScalingConfigurationInput
from volcenginesdkautoscaling.models.eip_for_describe_scaling_configurations_output import EipForDescribeScalingConfigurationsOutput
from volcenginesdkautoscaling.models.eip_for_modify_scaling_configuration_input import EipForModifyScalingConfigurationInput
from volcenginesdkautoscaling.models.enable_scaling_configuration_request import EnableScalingConfigurationRequest
from volcenginesdkautoscaling.models.enable_scaling_configuration_response import EnableScalingConfigurationResponse
from volcenginesdkautoscaling.models.enable_scaling_group_request import EnableScalingGroupRequest
from volcenginesdkautoscaling.models.enable_scaling_group_response import EnableScalingGroupResponse
from volcenginesdkautoscaling.models.enable_scaling_policy_request import EnableScalingPolicyRequest
from volcenginesdkautoscaling.models.enable_scaling_policy_response import EnableScalingPolicyResponse
from volcenginesdkautoscaling.models.instance_protection_result_for_set_instances_protection_output import InstanceProtectionResultForSetInstancesProtectionOutput
from volcenginesdkautoscaling.models.lifecycle_activity_for_describe_lifecycle_activities_output import LifecycleActivityForDescribeLifecycleActivitiesOutput
from volcenginesdkautoscaling.models.lifecycle_hook_for_describe_lifecycle_hooks_output import LifecycleHookForDescribeLifecycleHooksOutput
from volcenginesdkautoscaling.models.modify_lifecycle_hook_request import ModifyLifecycleHookRequest
from volcenginesdkautoscaling.models.modify_lifecycle_hook_response import ModifyLifecycleHookResponse
from volcenginesdkautoscaling.models.modify_scaling_configuration_request import ModifyScalingConfigurationRequest
from volcenginesdkautoscaling.models.modify_scaling_configuration_response import ModifyScalingConfigurationResponse
from volcenginesdkautoscaling.models.modify_scaling_group_request import ModifyScalingGroupRequest
from volcenginesdkautoscaling.models.modify_scaling_group_response import ModifyScalingGroupResponse
from volcenginesdkautoscaling.models.modify_scaling_policy_request import ModifyScalingPolicyRequest
from volcenginesdkautoscaling.models.modify_scaling_policy_response import ModifyScalingPolicyResponse
from volcenginesdkautoscaling.models.related_instance_for_describe_scaling_activities_output import RelatedInstanceForDescribeScalingActivitiesOutput
from volcenginesdkautoscaling.models.remove_instances_request import RemoveInstancesRequest
from volcenginesdkautoscaling.models.remove_instances_response import RemoveInstancesResponse
from volcenginesdkautoscaling.models.scaling_activity_for_describe_scaling_activities_output import ScalingActivityForDescribeScalingActivitiesOutput
from volcenginesdkautoscaling.models.scaling_configuration_for_describe_scaling_configurations_output import ScalingConfigurationForDescribeScalingConfigurationsOutput
from volcenginesdkautoscaling.models.scaling_group_for_describe_scaling_groups_output import ScalingGroupForDescribeScalingGroupsOutput
from volcenginesdkautoscaling.models.scaling_instance_for_describe_scaling_instances_output import ScalingInstanceForDescribeScalingInstancesOutput
from volcenginesdkautoscaling.models.scaling_policy_for_describe_scaling_policies_output import ScalingPolicyForDescribeScalingPoliciesOutput
from volcenginesdkautoscaling.models.scheduled_policy_for_create_scaling_policy_input import ScheduledPolicyForCreateScalingPolicyInput
from volcenginesdkautoscaling.models.scheduled_policy_for_describe_scaling_policies_output import ScheduledPolicyForDescribeScalingPoliciesOutput
from volcenginesdkautoscaling.models.scheduled_policy_for_modify_scaling_policy_input import ScheduledPolicyForModifyScalingPolicyInput
from volcenginesdkautoscaling.models.server_group_attribute_for_attach_server_groups_input import ServerGroupAttributeForAttachServerGroupsInput
from volcenginesdkautoscaling.models.server_group_attribute_for_create_scaling_group_input import ServerGroupAttributeForCreateScalingGroupInput
from volcenginesdkautoscaling.models.server_group_attribute_for_describe_scaling_groups_output import ServerGroupAttributeForDescribeScalingGroupsOutput
from volcenginesdkautoscaling.models.server_group_attribute_for_detach_server_groups_input import ServerGroupAttributeForDetachServerGroupsInput
from volcenginesdkautoscaling.models.set_instances_protection_request import SetInstancesProtectionRequest
from volcenginesdkautoscaling.models.set_instances_protection_response import SetInstancesProtectionResponse
from volcenginesdkautoscaling.models.volume_for_create_scaling_configuration_input import VolumeForCreateScalingConfigurationInput
from volcenginesdkautoscaling.models.volume_for_describe_scaling_configurations_output import VolumeForDescribeScalingConfigurationsOutput
from volcenginesdkautoscaling.models.volume_for_modify_scaling_configuration_input import VolumeForModifyScalingConfigurationInput



# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeLoadBalancerAttributesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_log': 'AccessLogForDescribeLoadBalancerAttributesOutput',
        'business_status': 'str',
        'create_time': 'str',
        'deleted_time': 'str',
        'description': 'str',
        'eip': 'EipForDescribeLoadBalancerAttributesOutput',
        'eip_address': 'str',
        'eip_id': 'str',
        'enabled': 'bool',
        'eni_address': 'str',
        'eni_id': 'str',
        'expired_time': 'str',
        'listeners': 'list[ListenerForDescribeLoadBalancerAttributesOutput]',
        'load_balancer_billing_type': 'int',
        'load_balancer_id': 'str',
        'load_balancer_name': 'str',
        'load_balancer_spec': 'str',
        'lock_reason': 'str',
        'log_topic_id': 'str',
        'master_zone_id': 'str',
        'modification_protection_reason': 'str',
        'modification_protection_status': 'str',
        'overdue_time': 'str',
        'project_name': 'str',
        'request_id': 'str',
        'server_groups': 'list[ServerGroupForDescribeLoadBalancerAttributesOutput]',
        'slave_zone_id': 'str',
        'status': 'str',
        'subnet_id': 'str',
        'tags': 'list[TagForDescribeLoadBalancerAttributesOutput]',
        'type': 'str',
        'update_time': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'access_log': 'AccessLog',
        'business_status': 'BusinessStatus',
        'create_time': 'CreateTime',
        'deleted_time': 'DeletedTime',
        'description': 'Description',
        'eip': 'Eip',
        'eip_address': 'EipAddress',
        'eip_id': 'EipID',
        'enabled': 'Enabled',
        'eni_address': 'EniAddress',
        'eni_id': 'EniID',
        'expired_time': 'ExpiredTime',
        'listeners': 'Listeners',
        'load_balancer_billing_type': 'LoadBalancerBillingType',
        'load_balancer_id': 'LoadBalancerId',
        'load_balancer_name': 'LoadBalancerName',
        'load_balancer_spec': 'LoadBalancerSpec',
        'lock_reason': 'LockReason',
        'log_topic_id': 'LogTopicId',
        'master_zone_id': 'MasterZoneId',
        'modification_protection_reason': 'ModificationProtectionReason',
        'modification_protection_status': 'ModificationProtectionStatus',
        'overdue_time': 'OverdueTime',
        'project_name': 'ProjectName',
        'request_id': 'RequestId',
        'server_groups': 'ServerGroups',
        'slave_zone_id': 'SlaveZoneId',
        'status': 'Status',
        'subnet_id': 'SubnetId',
        'tags': 'Tags',
        'type': 'Type',
        'update_time': 'UpdateTime',
        'vpc_id': 'VpcId'
    }

    def __init__(self, access_log=None, business_status=None, create_time=None, deleted_time=None, description=None, eip=None, eip_address=None, eip_id=None, enabled=None, eni_address=None, eni_id=None, expired_time=None, listeners=None, load_balancer_billing_type=None, load_balancer_id=None, load_balancer_name=None, load_balancer_spec=None, lock_reason=None, log_topic_id=None, master_zone_id=None, modification_protection_reason=None, modification_protection_status=None, overdue_time=None, project_name=None, request_id=None, server_groups=None, slave_zone_id=None, status=None, subnet_id=None, tags=None, type=None, update_time=None, vpc_id=None, _configuration=None):  # noqa: E501
        """DescribeLoadBalancerAttributesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._access_log = None
        self._business_status = None
        self._create_time = None
        self._deleted_time = None
        self._description = None
        self._eip = None
        self._eip_address = None
        self._eip_id = None
        self._enabled = None
        self._eni_address = None
        self._eni_id = None
        self._expired_time = None
        self._listeners = None
        self._load_balancer_billing_type = None
        self._load_balancer_id = None
        self._load_balancer_name = None
        self._load_balancer_spec = None
        self._lock_reason = None
        self._log_topic_id = None
        self._master_zone_id = None
        self._modification_protection_reason = None
        self._modification_protection_status = None
        self._overdue_time = None
        self._project_name = None
        self._request_id = None
        self._server_groups = None
        self._slave_zone_id = None
        self._status = None
        self._subnet_id = None
        self._tags = None
        self._type = None
        self._update_time = None
        self._vpc_id = None
        self.discriminator = None

        if access_log is not None:
            self.access_log = access_log
        if business_status is not None:
            self.business_status = business_status
        if create_time is not None:
            self.create_time = create_time
        if deleted_time is not None:
            self.deleted_time = deleted_time
        if description is not None:
            self.description = description
        if eip is not None:
            self.eip = eip
        if eip_address is not None:
            self.eip_address = eip_address
        if eip_id is not None:
            self.eip_id = eip_id
        if enabled is not None:
            self.enabled = enabled
        if eni_address is not None:
            self.eni_address = eni_address
        if eni_id is not None:
            self.eni_id = eni_id
        if expired_time is not None:
            self.expired_time = expired_time
        if listeners is not None:
            self.listeners = listeners
        if load_balancer_billing_type is not None:
            self.load_balancer_billing_type = load_balancer_billing_type
        if load_balancer_id is not None:
            self.load_balancer_id = load_balancer_id
        if load_balancer_name is not None:
            self.load_balancer_name = load_balancer_name
        if load_balancer_spec is not None:
            self.load_balancer_spec = load_balancer_spec
        if lock_reason is not None:
            self.lock_reason = lock_reason
        if log_topic_id is not None:
            self.log_topic_id = log_topic_id
        if master_zone_id is not None:
            self.master_zone_id = master_zone_id
        if modification_protection_reason is not None:
            self.modification_protection_reason = modification_protection_reason
        if modification_protection_status is not None:
            self.modification_protection_status = modification_protection_status
        if overdue_time is not None:
            self.overdue_time = overdue_time
        if project_name is not None:
            self.project_name = project_name
        if request_id is not None:
            self.request_id = request_id
        if server_groups is not None:
            self.server_groups = server_groups
        if slave_zone_id is not None:
            self.slave_zone_id = slave_zone_id
        if status is not None:
            self.status = status
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if tags is not None:
            self.tags = tags
        if type is not None:
            self.type = type
        if update_time is not None:
            self.update_time = update_time
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def access_log(self):
        """Gets the access_log of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The access_log of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: AccessLogForDescribeLoadBalancerAttributesOutput
        """
        return self._access_log

    @access_log.setter
    def access_log(self, access_log):
        """Sets the access_log of this DescribeLoadBalancerAttributesResponse.


        :param access_log: The access_log of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: AccessLogForDescribeLoadBalancerAttributesOutput
        """

        self._access_log = access_log

    @property
    def business_status(self):
        """Gets the business_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The business_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_status

    @business_status.setter
    def business_status(self, business_status):
        """Sets the business_status of this DescribeLoadBalancerAttributesResponse.


        :param business_status: The business_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._business_status = business_status

    @property
    def create_time(self):
        """Gets the create_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The create_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DescribeLoadBalancerAttributesResponse.


        :param create_time: The create_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def deleted_time(self):
        """Gets the deleted_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The deleted_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._deleted_time

    @deleted_time.setter
    def deleted_time(self, deleted_time):
        """Sets the deleted_time of this DescribeLoadBalancerAttributesResponse.


        :param deleted_time: The deleted_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._deleted_time = deleted_time

    @property
    def description(self):
        """Gets the description of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The description of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DescribeLoadBalancerAttributesResponse.


        :param description: The description of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def eip(self):
        """Gets the eip of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The eip of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: EipForDescribeLoadBalancerAttributesOutput
        """
        return self._eip

    @eip.setter
    def eip(self, eip):
        """Sets the eip of this DescribeLoadBalancerAttributesResponse.


        :param eip: The eip of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: EipForDescribeLoadBalancerAttributesOutput
        """

        self._eip = eip

    @property
    def eip_address(self):
        """Gets the eip_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The eip_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._eip_address

    @eip_address.setter
    def eip_address(self, eip_address):
        """Sets the eip_address of this DescribeLoadBalancerAttributesResponse.


        :param eip_address: The eip_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._eip_address = eip_address

    @property
    def eip_id(self):
        """Gets the eip_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The eip_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._eip_id

    @eip_id.setter
    def eip_id(self, eip_id):
        """Sets the eip_id of this DescribeLoadBalancerAttributesResponse.


        :param eip_id: The eip_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._eip_id = eip_id

    @property
    def enabled(self):
        """Gets the enabled of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The enabled of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DescribeLoadBalancerAttributesResponse.


        :param enabled: The enabled of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def eni_address(self):
        """Gets the eni_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The eni_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._eni_address

    @eni_address.setter
    def eni_address(self, eni_address):
        """Sets the eni_address of this DescribeLoadBalancerAttributesResponse.


        :param eni_address: The eni_address of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._eni_address = eni_address

    @property
    def eni_id(self):
        """Gets the eni_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The eni_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._eni_id

    @eni_id.setter
    def eni_id(self, eni_id):
        """Sets the eni_id of this DescribeLoadBalancerAttributesResponse.


        :param eni_id: The eni_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._eni_id = eni_id

    @property
    def expired_time(self):
        """Gets the expired_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The expired_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this DescribeLoadBalancerAttributesResponse.


        :param expired_time: The expired_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def listeners(self):
        """Gets the listeners of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The listeners of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: list[ListenerForDescribeLoadBalancerAttributesOutput]
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """Sets the listeners of this DescribeLoadBalancerAttributesResponse.


        :param listeners: The listeners of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: list[ListenerForDescribeLoadBalancerAttributesOutput]
        """

        self._listeners = listeners

    @property
    def load_balancer_billing_type(self):
        """Gets the load_balancer_billing_type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The load_balancer_billing_type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._load_balancer_billing_type

    @load_balancer_billing_type.setter
    def load_balancer_billing_type(self, load_balancer_billing_type):
        """Sets the load_balancer_billing_type of this DescribeLoadBalancerAttributesResponse.


        :param load_balancer_billing_type: The load_balancer_billing_type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: int
        """

        self._load_balancer_billing_type = load_balancer_billing_type

    @property
    def load_balancer_id(self):
        """Gets the load_balancer_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The load_balancer_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """Sets the load_balancer_id of this DescribeLoadBalancerAttributesResponse.


        :param load_balancer_id: The load_balancer_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._load_balancer_id = load_balancer_id

    @property
    def load_balancer_name(self):
        """Gets the load_balancer_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The load_balancer_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._load_balancer_name

    @load_balancer_name.setter
    def load_balancer_name(self, load_balancer_name):
        """Sets the load_balancer_name of this DescribeLoadBalancerAttributesResponse.


        :param load_balancer_name: The load_balancer_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._load_balancer_name = load_balancer_name

    @property
    def load_balancer_spec(self):
        """Gets the load_balancer_spec of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The load_balancer_spec of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._load_balancer_spec

    @load_balancer_spec.setter
    def load_balancer_spec(self, load_balancer_spec):
        """Sets the load_balancer_spec of this DescribeLoadBalancerAttributesResponse.


        :param load_balancer_spec: The load_balancer_spec of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._load_balancer_spec = load_balancer_spec

    @property
    def lock_reason(self):
        """Gets the lock_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The lock_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._lock_reason

    @lock_reason.setter
    def lock_reason(self, lock_reason):
        """Sets the lock_reason of this DescribeLoadBalancerAttributesResponse.


        :param lock_reason: The lock_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._lock_reason = lock_reason

    @property
    def log_topic_id(self):
        """Gets the log_topic_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The log_topic_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._log_topic_id

    @log_topic_id.setter
    def log_topic_id(self, log_topic_id):
        """Sets the log_topic_id of this DescribeLoadBalancerAttributesResponse.


        :param log_topic_id: The log_topic_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._log_topic_id = log_topic_id

    @property
    def master_zone_id(self):
        """Gets the master_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The master_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._master_zone_id

    @master_zone_id.setter
    def master_zone_id(self, master_zone_id):
        """Sets the master_zone_id of this DescribeLoadBalancerAttributesResponse.


        :param master_zone_id: The master_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._master_zone_id = master_zone_id

    @property
    def modification_protection_reason(self):
        """Gets the modification_protection_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The modification_protection_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._modification_protection_reason

    @modification_protection_reason.setter
    def modification_protection_reason(self, modification_protection_reason):
        """Sets the modification_protection_reason of this DescribeLoadBalancerAttributesResponse.


        :param modification_protection_reason: The modification_protection_reason of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._modification_protection_reason = modification_protection_reason

    @property
    def modification_protection_status(self):
        """Gets the modification_protection_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The modification_protection_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._modification_protection_status

    @modification_protection_status.setter
    def modification_protection_status(self, modification_protection_status):
        """Sets the modification_protection_status of this DescribeLoadBalancerAttributesResponse.


        :param modification_protection_status: The modification_protection_status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._modification_protection_status = modification_protection_status

    @property
    def overdue_time(self):
        """Gets the overdue_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The overdue_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._overdue_time

    @overdue_time.setter
    def overdue_time(self, overdue_time):
        """Sets the overdue_time of this DescribeLoadBalancerAttributesResponse.


        :param overdue_time: The overdue_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._overdue_time = overdue_time

    @property
    def project_name(self):
        """Gets the project_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The project_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeLoadBalancerAttributesResponse.


        :param project_name: The project_name of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def request_id(self):
        """Gets the request_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The request_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DescribeLoadBalancerAttributesResponse.


        :param request_id: The request_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def server_groups(self):
        """Gets the server_groups of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The server_groups of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: list[ServerGroupForDescribeLoadBalancerAttributesOutput]
        """
        return self._server_groups

    @server_groups.setter
    def server_groups(self, server_groups):
        """Sets the server_groups of this DescribeLoadBalancerAttributesResponse.


        :param server_groups: The server_groups of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: list[ServerGroupForDescribeLoadBalancerAttributesOutput]
        """

        self._server_groups = server_groups

    @property
    def slave_zone_id(self):
        """Gets the slave_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The slave_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._slave_zone_id

    @slave_zone_id.setter
    def slave_zone_id(self, slave_zone_id):
        """Sets the slave_zone_id of this DescribeLoadBalancerAttributesResponse.


        :param slave_zone_id: The slave_zone_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._slave_zone_id = slave_zone_id

    @property
    def status(self):
        """Gets the status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeLoadBalancerAttributesResponse.


        :param status: The status of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def subnet_id(self):
        """Gets the subnet_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The subnet_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this DescribeLoadBalancerAttributesResponse.


        :param subnet_id: The subnet_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def tags(self):
        """Gets the tags of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The tags of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: list[TagForDescribeLoadBalancerAttributesOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this DescribeLoadBalancerAttributesResponse.


        :param tags: The tags of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: list[TagForDescribeLoadBalancerAttributesOutput]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DescribeLoadBalancerAttributesResponse.


        :param type: The type of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def update_time(self):
        """Gets the update_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The update_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DescribeLoadBalancerAttributesResponse.


        :param update_time: The update_time of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501


        :return: The vpc_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DescribeLoadBalancerAttributesResponse.


        :param vpc_id: The vpc_id of this DescribeLoadBalancerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeLoadBalancerAttributesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeLoadBalancerAttributesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeLoadBalancerAttributesResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    natgateway

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeDnatEntriesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dnat_entry_ids': 'list[str]',
        'dnat_entry_name': 'str',
        'external_ip': 'str',
        'external_port': 'str',
        'internal_ip': 'str',
        'internal_port': 'str',
        'nat_gateway_id': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'protocol': 'str'
    }

    attribute_map = {
        'dnat_entry_ids': 'DnatEntryIds',
        'dnat_entry_name': 'DnatEntryName',
        'external_ip': 'ExternalIp',
        'external_port': 'ExternalPort',
        'internal_ip': 'InternalIp',
        'internal_port': 'InternalPort',
        'nat_gateway_id': 'NatGatewayId',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'protocol': 'Protocol'
    }

    def __init__(self, dnat_entry_ids=None, dnat_entry_name=None, external_ip=None, external_port=None, internal_ip=None, internal_port=None, nat_gateway_id=None, page_number=None, page_size=None, protocol=None, _configuration=None):  # noqa: E501
        """DescribeDnatEntriesRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._dnat_entry_ids = None
        self._dnat_entry_name = None
        self._external_ip = None
        self._external_port = None
        self._internal_ip = None
        self._internal_port = None
        self._nat_gateway_id = None
        self._page_number = None
        self._page_size = None
        self._protocol = None
        self.discriminator = None

        if dnat_entry_ids is not None:
            self.dnat_entry_ids = dnat_entry_ids
        if dnat_entry_name is not None:
            self.dnat_entry_name = dnat_entry_name
        if external_ip is not None:
            self.external_ip = external_ip
        if external_port is not None:
            self.external_port = external_port
        if internal_ip is not None:
            self.internal_ip = internal_ip
        if internal_port is not None:
            self.internal_port = internal_port
        if nat_gateway_id is not None:
            self.nat_gateway_id = nat_gateway_id
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if protocol is not None:
            self.protocol = protocol

    @property
    def dnat_entry_ids(self):
        """Gets the dnat_entry_ids of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The dnat_entry_ids of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._dnat_entry_ids

    @dnat_entry_ids.setter
    def dnat_entry_ids(self, dnat_entry_ids):
        """Sets the dnat_entry_ids of this DescribeDnatEntriesRequest.


        :param dnat_entry_ids: The dnat_entry_ids of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: list[str]
        """

        self._dnat_entry_ids = dnat_entry_ids

    @property
    def dnat_entry_name(self):
        """Gets the dnat_entry_name of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The dnat_entry_name of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._dnat_entry_name

    @dnat_entry_name.setter
    def dnat_entry_name(self, dnat_entry_name):
        """Sets the dnat_entry_name of this DescribeDnatEntriesRequest.


        :param dnat_entry_name: The dnat_entry_name of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._dnat_entry_name = dnat_entry_name

    @property
    def external_ip(self):
        """Gets the external_ip of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The external_ip of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._external_ip

    @external_ip.setter
    def external_ip(self, external_ip):
        """Sets the external_ip of this DescribeDnatEntriesRequest.


        :param external_ip: The external_ip of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._external_ip = external_ip

    @property
    def external_port(self):
        """Gets the external_port of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The external_port of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._external_port

    @external_port.setter
    def external_port(self, external_port):
        """Sets the external_port of this DescribeDnatEntriesRequest.


        :param external_port: The external_port of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._external_port = external_port

    @property
    def internal_ip(self):
        """Gets the internal_ip of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The internal_ip of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_ip

    @internal_ip.setter
    def internal_ip(self, internal_ip):
        """Sets the internal_ip of this DescribeDnatEntriesRequest.


        :param internal_ip: The internal_ip of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._internal_ip = internal_ip

    @property
    def internal_port(self):
        """Gets the internal_port of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The internal_port of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_port

    @internal_port.setter
    def internal_port(self, internal_port):
        """Sets the internal_port of this DescribeDnatEntriesRequest.


        :param internal_port: The internal_port of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._internal_port = internal_port

    @property
    def nat_gateway_id(self):
        """Gets the nat_gateway_id of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The nat_gateway_id of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._nat_gateway_id

    @nat_gateway_id.setter
    def nat_gateway_id(self, nat_gateway_id):
        """Sets the nat_gateway_id of this DescribeDnatEntriesRequest.


        :param nat_gateway_id: The nat_gateway_id of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._nat_gateway_id = nat_gateway_id

    @property
    def page_number(self):
        """Gets the page_number of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The page_number of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeDnatEntriesRequest.


        :param page_number: The page_number of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The page_size of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeDnatEntriesRequest.


        :param page_size: The page_size of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                page_size is not None and page_size > 100):  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must be a value less than or equal to `100`")  # noqa: E501

        self._page_size = page_size

    @property
    def protocol(self):
        """Gets the protocol of this DescribeDnatEntriesRequest.  # noqa: E501


        :return: The protocol of this DescribeDnatEntriesRequest.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DescribeDnatEntriesRequest.


        :param protocol: The protocol of this DescribeDnatEntriesRequest.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeDnatEntriesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeDnatEntriesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeDnatEntriesRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    natgateway

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdknatgateway.api.natgateway_api import NATGATEWAYApi

# import models into sdk package
from volcenginesdknatgateway.models.create_dnat_entry_request import CreateDnatEntryRequest
from volcenginesdknatgateway.models.create_dnat_entry_response import CreateDnatEntryResponse
from volcenginesdknatgateway.models.create_nat_gateway_request import CreateNatGatewayRequest
from volcenginesdknatgateway.models.create_nat_gateway_response import CreateNatGatewayResponse
from volcenginesdknatgateway.models.create_snat_entry_request import CreateSnatEntryRequest
from volcenginesdknatgateway.models.create_snat_entry_response import CreateSnatEntryResponse
from volcenginesdknatgateway.models.delete_dnat_entry_request import DeleteDnatEntryRequest
from volcenginesdknatgateway.models.delete_dnat_entry_response import DeleteDnatEntryResponse
from volcenginesdknatgateway.models.delete_nat_gateway_request import DeleteNatGatewayRequest
from volcenginesdknatgateway.models.delete_nat_gateway_response import DeleteNatGatewayResponse
from volcenginesdknatgateway.models.delete_snat_entry_request import DeleteSnatEntryRequest
from volcenginesdknatgateway.models.delete_snat_entry_response import DeleteSnatEntryResponse
from volcenginesdknatgateway.models.describe_dnat_entries_request import DescribeDnatEntriesRequest
from volcenginesdknatgateway.models.describe_dnat_entries_response import DescribeDnatEntriesResponse
from volcenginesdknatgateway.models.describe_dnat_entry_attributes_request import DescribeDnatEntryAttributesRequest
from volcenginesdknatgateway.models.describe_dnat_entry_attributes_response import DescribeDnatEntryAttributesResponse
from volcenginesdknatgateway.models.describe_nat_gateway_attributes_request import DescribeNatGatewayAttributesRequest
from volcenginesdknatgateway.models.describe_nat_gateway_attributes_response import DescribeNatGatewayAttributesResponse
from volcenginesdknatgateway.models.describe_nat_gateways_request import DescribeNatGatewaysRequest
from volcenginesdknatgateway.models.describe_nat_gateways_response import DescribeNatGatewaysResponse
from volcenginesdknatgateway.models.describe_snat_entries_request import DescribeSnatEntriesRequest
from volcenginesdknatgateway.models.describe_snat_entries_response import DescribeSnatEntriesResponse
from volcenginesdknatgateway.models.describe_snat_entry_attributes_request import DescribeSnatEntryAttributesRequest
from volcenginesdknatgateway.models.describe_snat_entry_attributes_response import DescribeSnatEntryAttributesResponse
from volcenginesdknatgateway.models.dnat_entry_for_describe_dnat_entries_output import DnatEntryForDescribeDnatEntriesOutput
from volcenginesdknatgateway.models.eip_address_for_describe_nat_gateway_attributes_output import EipAddressForDescribeNatGatewayAttributesOutput
from volcenginesdknatgateway.models.eip_address_for_describe_nat_gateways_output import EipAddressForDescribeNatGatewaysOutput
from volcenginesdknatgateway.models.list_nat_gateway_available_zones_request import ListNatGatewayAvailableZonesRequest
from volcenginesdknatgateway.models.list_nat_gateway_available_zones_response import ListNatGatewayAvailableZonesResponse
from volcenginesdknatgateway.models.modify_dnat_entry_attributes_request import ModifyDnatEntryAttributesRequest
from volcenginesdknatgateway.models.modify_dnat_entry_attributes_response import ModifyDnatEntryAttributesResponse
from volcenginesdknatgateway.models.modify_nat_gateway_attributes_request import ModifyNatGatewayAttributesRequest
from volcenginesdknatgateway.models.modify_nat_gateway_attributes_response import ModifyNatGatewayAttributesResponse
from volcenginesdknatgateway.models.modify_snat_entry_attributes_request import ModifySnatEntryAttributesRequest
from volcenginesdknatgateway.models.modify_snat_entry_attributes_response import ModifySnatEntryAttributesResponse
from volcenginesdknatgateway.models.nat_gateway_for_describe_nat_gateways_output import NatGatewayForDescribeNatGatewaysOutput
from volcenginesdknatgateway.models.snat_entry_for_describe_snat_entries_output import SnatEntryForDescribeSnatEntriesOutput
from volcenginesdknatgateway.models.tag_filter_for_describe_nat_gateways_input import TagFilterForDescribeNatGatewaysInput
from volcenginesdknatgateway.models.tag_for_create_nat_gateway_input import TagForCreateNatGatewayInput
from volcenginesdknatgateway.models.tag_for_describe_nat_gateway_attributes_output import TagForDescribeNatGatewayAttributesOutput
from volcenginesdknatgateway.models.tag_for_describe_nat_gateways_output import TagForDescribeNatGatewaysOutput
from volcenginesdknatgateway.models.zone_for_list_nat_gateway_available_zones_output import ZoneForListNatGatewayAvailableZonesOutput



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ScalingPolicyForDescribeScalingPoliciesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'adjustment_type': 'str',
        'adjustment_value': 'int',
        'alarm_policy': 'AlarmPolicyForDescribeScalingPoliciesOutput',
        'cooldown': 'int',
        'scaling_group_id': 'str',
        'scaling_policy_id': 'str',
        'scaling_policy_name': 'str',
        'scaling_policy_type': 'str',
        'scheduled_policy': 'ScheduledPolicyForDescribeScalingPoliciesOutput',
        'status': 'str'
    }

    attribute_map = {
        'adjustment_type': 'AdjustmentType',
        'adjustment_value': 'AdjustmentValue',
        'alarm_policy': 'AlarmPolicy',
        'cooldown': 'Cooldown',
        'scaling_group_id': 'ScalingGroupId',
        'scaling_policy_id': 'ScalingPolicyId',
        'scaling_policy_name': 'ScalingPolicyName',
        'scaling_policy_type': 'ScalingPolicyType',
        'scheduled_policy': 'ScheduledPolicy',
        'status': 'Status'
    }

    def __init__(self, adjustment_type=None, adjustment_value=None, alarm_policy=None, cooldown=None, scaling_group_id=None, scaling_policy_id=None, scaling_policy_name=None, scaling_policy_type=None, scheduled_policy=None, status=None, _configuration=None):  # noqa: E501
        """ScalingPolicyForDescribeScalingPoliciesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._adjustment_type = None
        self._adjustment_value = None
        self._alarm_policy = None
        self._cooldown = None
        self._scaling_group_id = None
        self._scaling_policy_id = None
        self._scaling_policy_name = None
        self._scaling_policy_type = None
        self._scheduled_policy = None
        self._status = None
        self.discriminator = None

        if adjustment_type is not None:
            self.adjustment_type = adjustment_type
        if adjustment_value is not None:
            self.adjustment_value = adjustment_value
        if alarm_policy is not None:
            self.alarm_policy = alarm_policy
        if cooldown is not None:
            self.cooldown = cooldown
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id
        if scaling_policy_id is not None:
            self.scaling_policy_id = scaling_policy_id
        if scaling_policy_name is not None:
            self.scaling_policy_name = scaling_policy_name
        if scaling_policy_type is not None:
            self.scaling_policy_type = scaling_policy_type
        if scheduled_policy is not None:
            self.scheduled_policy = scheduled_policy
        if status is not None:
            self.status = status

    @property
    def adjustment_type(self):
        """Gets the adjustment_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The adjustment_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._adjustment_type

    @adjustment_type.setter
    def adjustment_type(self, adjustment_type):
        """Sets the adjustment_type of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param adjustment_type: The adjustment_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._adjustment_type = adjustment_type

    @property
    def adjustment_value(self):
        """Gets the adjustment_value of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The adjustment_value of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: int
        """
        return self._adjustment_value

    @adjustment_value.setter
    def adjustment_value(self, adjustment_value):
        """Sets the adjustment_value of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param adjustment_value: The adjustment_value of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: int
        """

        self._adjustment_value = adjustment_value

    @property
    def alarm_policy(self):
        """Gets the alarm_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The alarm_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: AlarmPolicyForDescribeScalingPoliciesOutput
        """
        return self._alarm_policy

    @alarm_policy.setter
    def alarm_policy(self, alarm_policy):
        """Sets the alarm_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param alarm_policy: The alarm_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: AlarmPolicyForDescribeScalingPoliciesOutput
        """

        self._alarm_policy = alarm_policy

    @property
    def cooldown(self):
        """Gets the cooldown of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The cooldown of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: int
        """
        return self._cooldown

    @cooldown.setter
    def cooldown(self, cooldown):
        """Sets the cooldown of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param cooldown: The cooldown of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: int
        """

        self._cooldown = cooldown

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The scaling_group_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param scaling_group_id: The scaling_group_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    @property
    def scaling_policy_id(self):
        """Gets the scaling_policy_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The scaling_policy_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_policy_id

    @scaling_policy_id.setter
    def scaling_policy_id(self, scaling_policy_id):
        """Sets the scaling_policy_id of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param scaling_policy_id: The scaling_policy_id of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_policy_id = scaling_policy_id

    @property
    def scaling_policy_name(self):
        """Gets the scaling_policy_name of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The scaling_policy_name of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_policy_name

    @scaling_policy_name.setter
    def scaling_policy_name(self, scaling_policy_name):
        """Sets the scaling_policy_name of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param scaling_policy_name: The scaling_policy_name of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_policy_name = scaling_policy_name

    @property
    def scaling_policy_type(self):
        """Gets the scaling_policy_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The scaling_policy_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._scaling_policy_type

    @scaling_policy_type.setter
    def scaling_policy_type(self, scaling_policy_type):
        """Sets the scaling_policy_type of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param scaling_policy_type: The scaling_policy_type of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._scaling_policy_type = scaling_policy_type

    @property
    def scheduled_policy(self):
        """Gets the scheduled_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The scheduled_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: ScheduledPolicyForDescribeScalingPoliciesOutput
        """
        return self._scheduled_policy

    @scheduled_policy.setter
    def scheduled_policy(self, scheduled_policy):
        """Sets the scheduled_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param scheduled_policy: The scheduled_policy of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: ScheduledPolicyForDescribeScalingPoliciesOutput
        """

        self._scheduled_policy = scheduled_policy

    @property
    def status(self):
        """Gets the status of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501


        :return: The status of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ScalingPolicyForDescribeScalingPoliciesOutput.


        :param status: The status of this ScalingPolicyForDescribeScalingPoliciesOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScalingPolicyForDescribeScalingPoliciesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScalingPolicyForDescribeScalingPoliciesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScalingPolicyForDescribeScalingPoliciesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeStatisticsForListNodePoolsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'creating_count': 'int',
        'deleting_count': 'int',
        'failed_count': 'int',
        'running_count': 'int',
        'total_count': 'int',
        'updating_count': 'int'
    }

    attribute_map = {
        'creating_count': 'CreatingCount',
        'deleting_count': 'DeletingCount',
        'failed_count': 'FailedCount',
        'running_count': 'RunningCount',
        'total_count': 'TotalCount',
        'updating_count': 'UpdatingCount'
    }

    def __init__(self, creating_count=None, deleting_count=None, failed_count=None, running_count=None, total_count=None, updating_count=None, _configuration=None):  # noqa: E501
        """NodeStatisticsForListNodePoolsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._creating_count = None
        self._deleting_count = None
        self._failed_count = None
        self._running_count = None
        self._total_count = None
        self._updating_count = None
        self.discriminator = None

        if creating_count is not None:
            self.creating_count = creating_count
        if deleting_count is not None:
            self.deleting_count = deleting_count
        if failed_count is not None:
            self.failed_count = failed_count
        if running_count is not None:
            self.running_count = running_count
        if total_count is not None:
            self.total_count = total_count
        if updating_count is not None:
            self.updating_count = updating_count

    @property
    def creating_count(self):
        """Gets the creating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The creating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._creating_count

    @creating_count.setter
    def creating_count(self, creating_count):
        """Sets the creating_count of this NodeStatisticsForListNodePoolsOutput.


        :param creating_count: The creating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._creating_count = creating_count

    @property
    def deleting_count(self):
        """Gets the deleting_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The deleting_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._deleting_count

    @deleting_count.setter
    def deleting_count(self, deleting_count):
        """Sets the deleting_count of this NodeStatisticsForListNodePoolsOutput.


        :param deleting_count: The deleting_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._deleting_count = deleting_count

    @property
    def failed_count(self):
        """Gets the failed_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The failed_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this NodeStatisticsForListNodePoolsOutput.


        :param failed_count: The failed_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._failed_count = failed_count

    @property
    def running_count(self):
        """Gets the running_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The running_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._running_count

    @running_count.setter
    def running_count(self, running_count):
        """Sets the running_count of this NodeStatisticsForListNodePoolsOutput.


        :param running_count: The running_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._running_count = running_count

    @property
    def total_count(self):
        """Gets the total_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The total_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this NodeStatisticsForListNodePoolsOutput.


        :param total_count: The total_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def updating_count(self):
        """Gets the updating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501


        :return: The updating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :rtype: int
        """
        return self._updating_count

    @updating_count.setter
    def updating_count(self, updating_count):
        """Sets the updating_count of this NodeStatisticsForListNodePoolsOutput.


        :param updating_count: The updating_count of this NodeStatisticsForListNodePoolsOutput.  # noqa: E501
        :type: int
        """

        self._updating_count = updating_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeStatisticsForListNodePoolsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeStatisticsForListNodePoolsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeStatisticsForListNodePoolsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeConfigForCreateDefaultNodePoolInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'initialize_script': 'str',
        'name_prefix': 'str',
        'security': 'SecurityForCreateDefaultNodePoolInput',
        'tags': 'list[TagForCreateDefaultNodePoolInput]'
    }

    attribute_map = {
        'initialize_script': 'InitializeScript',
        'name_prefix': 'NamePrefix',
        'security': 'Security',
        'tags': 'Tags'
    }

    def __init__(self, initialize_script=None, name_prefix=None, security=None, tags=None, _configuration=None):  # noqa: E501
        """NodeConfigForCreateDefaultNodePoolInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._initialize_script = None
        self._name_prefix = None
        self._security = None
        self._tags = None
        self.discriminator = None

        if initialize_script is not None:
            self.initialize_script = initialize_script
        if name_prefix is not None:
            self.name_prefix = name_prefix
        if security is not None:
            self.security = security
        if tags is not None:
            self.tags = tags

    @property
    def initialize_script(self):
        """Gets the initialize_script of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501


        :return: The initialize_script of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._initialize_script

    @initialize_script.setter
    def initialize_script(self, initialize_script):
        """Sets the initialize_script of this NodeConfigForCreateDefaultNodePoolInput.


        :param initialize_script: The initialize_script of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :type: str
        """

        self._initialize_script = initialize_script

    @property
    def name_prefix(self):
        """Gets the name_prefix of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501


        :return: The name_prefix of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._name_prefix

    @name_prefix.setter
    def name_prefix(self, name_prefix):
        """Sets the name_prefix of this NodeConfigForCreateDefaultNodePoolInput.


        :param name_prefix: The name_prefix of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :type: str
        """

        self._name_prefix = name_prefix

    @property
    def security(self):
        """Gets the security of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501


        :return: The security of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :rtype: SecurityForCreateDefaultNodePoolInput
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this NodeConfigForCreateDefaultNodePoolInput.


        :param security: The security of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :type: SecurityForCreateDefaultNodePoolInput
        """

        self._security = security

    @property
    def tags(self):
        """Gets the tags of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501


        :return: The tags of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :rtype: list[TagForCreateDefaultNodePoolInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this NodeConfigForCreateDefaultNodePoolInput.


        :param tags: The tags of this NodeConfigForCreateDefaultNodePoolInput.  # noqa: E501
        :type: list[TagForCreateDefaultNodePoolInput]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeConfigForCreateDefaultNodePoolInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeConfigForCreateDefaultNodePoolInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeConfigForCreateDefaultNodePoolInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    volc_observe

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdkvolcobserve.api.volc_observe_api import VOLCOBSERVEApi

# import models into sdk package
from volcenginesdkvolcobserve.models.data_for_get_metric_data_output import DataForGetMetricDataOutput
from volcenginesdkvolcobserve.models.data_point_for_get_metric_data_output import DataPointForGetMetricDataOutput
from volcenginesdkvolcobserve.models.dimension_for_get_metric_data_input import DimensionForGetMetricDataInput
from volcenginesdkvolcobserve.models.dimension_for_get_metric_data_output import DimensionForGetMetricDataOutput
from volcenginesdkvolcobserve.models.get_metric_data_request import GetMetricDataRequest
from volcenginesdkvolcobserve.models.get_metric_data_response import GetMetricDataResponse
from volcenginesdkvolcobserve.models.instance_for_get_metric_data_input import InstanceForGetMetricDataInput
from volcenginesdkvolcobserve.models.metric_data_result_for_get_metric_data_output import MetricDataResultForGetMetricDataOutput



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class AllowListForDescribeAllowListsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_list_desc': 'str',
        'allow_list_ip_num': 'int',
        'allow_list_id': 'str',
        'allow_list_name': 'str',
        'allow_list_type': 'str',
        'associated_instance_num': 'int'
    }

    attribute_map = {
        'allow_list_desc': 'AllowListDesc',
        'allow_list_ip_num': 'AllowListIPNum',
        'allow_list_id': 'AllowListId',
        'allow_list_name': 'AllowListName',
        'allow_list_type': 'AllowListType',
        'associated_instance_num': 'AssociatedInstanceNum'
    }

    def __init__(self, allow_list_desc=None, allow_list_ip_num=None, allow_list_id=None, allow_list_name=None, allow_list_type=None, associated_instance_num=None, _configuration=None):  # noqa: E501
        """AllowListForDescribeAllowListsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allow_list_desc = None
        self._allow_list_ip_num = None
        self._allow_list_id = None
        self._allow_list_name = None
        self._allow_list_type = None
        self._associated_instance_num = None
        self.discriminator = None

        if allow_list_desc is not None:
            self.allow_list_desc = allow_list_desc
        if allow_list_ip_num is not None:
            self.allow_list_ip_num = allow_list_ip_num
        if allow_list_id is not None:
            self.allow_list_id = allow_list_id
        if allow_list_name is not None:
            self.allow_list_name = allow_list_name
        if allow_list_type is not None:
            self.allow_list_type = allow_list_type
        if associated_instance_num is not None:
            self.associated_instance_num = associated_instance_num

    @property
    def allow_list_desc(self):
        """Gets the allow_list_desc of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The allow_list_desc of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: str
        """
        return self._allow_list_desc

    @allow_list_desc.setter
    def allow_list_desc(self, allow_list_desc):
        """Sets the allow_list_desc of this AllowListForDescribeAllowListsOutput.


        :param allow_list_desc: The allow_list_desc of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: str
        """

        self._allow_list_desc = allow_list_desc

    @property
    def allow_list_ip_num(self):
        """Gets the allow_list_ip_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The allow_list_ip_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: int
        """
        return self._allow_list_ip_num

    @allow_list_ip_num.setter
    def allow_list_ip_num(self, allow_list_ip_num):
        """Sets the allow_list_ip_num of this AllowListForDescribeAllowListsOutput.


        :param allow_list_ip_num: The allow_list_ip_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: int
        """

        self._allow_list_ip_num = allow_list_ip_num

    @property
    def allow_list_id(self):
        """Gets the allow_list_id of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The allow_list_id of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: str
        """
        return self._allow_list_id

    @allow_list_id.setter
    def allow_list_id(self, allow_list_id):
        """Sets the allow_list_id of this AllowListForDescribeAllowListsOutput.


        :param allow_list_id: The allow_list_id of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: str
        """

        self._allow_list_id = allow_list_id

    @property
    def allow_list_name(self):
        """Gets the allow_list_name of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The allow_list_name of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: str
        """
        return self._allow_list_name

    @allow_list_name.setter
    def allow_list_name(self, allow_list_name):
        """Sets the allow_list_name of this AllowListForDescribeAllowListsOutput.


        :param allow_list_name: The allow_list_name of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: str
        """

        self._allow_list_name = allow_list_name

    @property
    def allow_list_type(self):
        """Gets the allow_list_type of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The allow_list_type of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: str
        """
        return self._allow_list_type

    @allow_list_type.setter
    def allow_list_type(self, allow_list_type):
        """Sets the allow_list_type of this AllowListForDescribeAllowListsOutput.


        :param allow_list_type: The allow_list_type of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: str
        """

        self._allow_list_type = allow_list_type

    @property
    def associated_instance_num(self):
        """Gets the associated_instance_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501


        :return: The associated_instance_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :rtype: int
        """
        return self._associated_instance_num

    @associated_instance_num.setter
    def associated_instance_num(self, associated_instance_num):
        """Sets the associated_instance_num of this AllowListForDescribeAllowListsOutput.


        :param associated_instance_num: The associated_instance_num of this AllowListForDescribeAllowListsOutput.  # noqa: E501
        :type: int
        """

        self._associated_instance_num = associated_instance_num

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AllowListForDescribeAllowListsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AllowListForDescribeAllowListsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AllowListForDescribeAllowListsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from volcenginesdkrdsmysql.api.rds_mysql_api import RDSMYSQLApi

# import models into sdk package
from volcenginesdkrdsmysql.models.allow_list_for_describe_allow_lists_output import AllowListForDescribeAllowListsOutput
from volcenginesdkrdsmysql.models.associate_allow_list_request import AssociateAllowListRequest
from volcenginesdkrdsmysql.models.associate_allow_list_response import AssociateAllowListResponse
from volcenginesdkrdsmysql.models.associated_instance_for_describe_allow_list_detail_output import AssociatedInstanceForDescribeAllowListDetailOutput
from volcenginesdkrdsmysql.models.basic_info_for_describe_db_instance_output import BasicInfoForDescribeDBInstanceOutput
from volcenginesdkrdsmysql.models.connection_info_for_describe_db_instance_connection_output import ConnectionInfoForDescribeDBInstanceConnectionOutput
from volcenginesdkrdsmysql.models.connection_info_for_describe_db_instance_output import ConnectionInfoForDescribeDBInstanceOutput
from volcenginesdkrdsmysql.models.copy_parameter_template_request import CopyParameterTemplateRequest
from volcenginesdkrdsmysql.models.copy_parameter_template_response import CopyParameterTemplateResponse
from volcenginesdkrdsmysql.models.create_account_request import CreateAccountRequest
from volcenginesdkrdsmysql.models.create_account_response import CreateAccountResponse
from volcenginesdkrdsmysql.models.create_allow_list_request import CreateAllowListRequest
from volcenginesdkrdsmysql.models.create_allow_list_response import CreateAllowListResponse
from volcenginesdkrdsmysql.models.create_backup_request import CreateBackupRequest
from volcenginesdkrdsmysql.models.create_backup_response import CreateBackupResponse
from volcenginesdkrdsmysql.models.create_db_instance_ip_list_request import CreateDBInstanceIPListRequest
from volcenginesdkrdsmysql.models.create_db_instance_ip_list_response import CreateDBInstanceIPListResponse
from volcenginesdkrdsmysql.models.create_db_instance_request import CreateDBInstanceRequest
from volcenginesdkrdsmysql.models.create_db_instance_response import CreateDBInstanceResponse
from volcenginesdkrdsmysql.models.create_database_request import CreateDatabaseRequest
from volcenginesdkrdsmysql.models.create_database_response import CreateDatabaseResponse
from volcenginesdkrdsmysql.models.create_parameter_template_request import CreateParameterTemplateRequest
from volcenginesdkrdsmysql.models.create_parameter_template_response import CreateParameterTemplateResponse
from volcenginesdkrdsmysql.models.db_privilege_for_list_accounts_output import DBPrivilegeForListAccountsOutput
from volcenginesdkrdsmysql.models.data_for_list_accounts_output import DataForListAccountsOutput
from volcenginesdkrdsmysql.models.data_for_list_backups_output import DataForListBackupsOutput
from volcenginesdkrdsmysql.models.data_for_list_db_instance_ip_lists_output import DataForListDBInstanceIPListsOutput
from volcenginesdkrdsmysql.models.data_for_list_db_instances_output import DataForListDBInstancesOutput
from volcenginesdkrdsmysql.models.data_for_list_databases_output import DataForListDatabasesOutput
from volcenginesdkrdsmysql.models.data_for_list_instance_params_history_output import DataForListInstanceParamsHistoryOutput
from volcenginesdkrdsmysql.models.data_for_list_instance_params_output import DataForListInstanceParamsOutput
from volcenginesdkrdsmysql.models.data_for_list_parameter_templates_output import DataForListParameterTemplatesOutput
from volcenginesdkrdsmysql.models.data_for_list_regions_output import DataForListRegionsOutput
from volcenginesdkrdsmysql.models.data_for_list_vpcs_output import DataForListVpcsOutput
from volcenginesdkrdsmysql.models.data_for_list_zones_output import DataForListZonesOutput
from volcenginesdkrdsmysql.models.delete_account_request import DeleteAccountRequest
from volcenginesdkrdsmysql.models.delete_account_response import DeleteAccountResponse
from volcenginesdkrdsmysql.models.delete_allow_list_request import DeleteAllowListRequest
from volcenginesdkrdsmysql.models.delete_allow_list_response import DeleteAllowListResponse
from volcenginesdkrdsmysql.models.delete_db_instance_ip_list_request import DeleteDBInstanceIPListRequest
from volcenginesdkrdsmysql.models.delete_db_instance_ip_list_response import DeleteDBInstanceIPListResponse
from volcenginesdkrdsmysql.models.delete_db_instance_request import DeleteDBInstanceRequest
from volcenginesdkrdsmysql.models.delete_db_instance_response import DeleteDBInstanceResponse
from volcenginesdkrdsmysql.models.delete_database_request import DeleteDatabaseRequest
from volcenginesdkrdsmysql.models.delete_database_response import DeleteDatabaseResponse
from volcenginesdkrdsmysql.models.delete_parameter_template_request import DeleteParameterTemplateRequest
from volcenginesdkrdsmysql.models.delete_parameter_template_response import DeleteParameterTemplateResponse
from volcenginesdkrdsmysql.models.describe_allow_list_detail_request import DescribeAllowListDetailRequest
from volcenginesdkrdsmysql.models.describe_allow_list_detail_response import DescribeAllowListDetailResponse
from volcenginesdkrdsmysql.models.describe_allow_lists_request import DescribeAllowListsRequest
from volcenginesdkrdsmysql.models.describe_allow_lists_response import DescribeAllowListsResponse
from volcenginesdkrdsmysql.models.describe_apply_parameter_template_request import DescribeApplyParameterTemplateRequest
from volcenginesdkrdsmysql.models.describe_apply_parameter_template_response import DescribeApplyParameterTemplateResponse
from volcenginesdkrdsmysql.models.describe_db_instance_connection_request import DescribeDBInstanceConnectionRequest
from volcenginesdkrdsmysql.models.describe_db_instance_connection_response import DescribeDBInstanceConnectionResponse
from volcenginesdkrdsmysql.models.describe_db_instance_request import DescribeDBInstanceRequest
from volcenginesdkrdsmysql.models.describe_db_instance_response import DescribeDBInstanceResponse
from volcenginesdkrdsmysql.models.describe_parameter_template_request import DescribeParameterTemplateRequest
from volcenginesdkrdsmysql.models.describe_parameter_template_response import DescribeParameterTemplateResponse
from volcenginesdkrdsmysql.models.describe_recoverable_time_request import DescribeRecoverableTimeRequest
from volcenginesdkrdsmysql.models.describe_recoverable_time_response import DescribeRecoverableTimeResponse
from volcenginesdkrdsmysql.models.disassociate_allow_list_request import DisassociateAllowListRequest
from volcenginesdkrdsmysql.models.disassociate_allow_list_response import DisassociateAllowListResponse
from volcenginesdkrdsmysql.models.grant_account_privilege_request import GrantAccountPrivilegeRequest
from volcenginesdkrdsmysql.models.grant_account_privilege_response import GrantAccountPrivilegeResponse
from volcenginesdkrdsmysql.models.instance_spec_for_describe_db_instance_output import InstanceSpecForDescribeDBInstanceOutput
from volcenginesdkrdsmysql.models.instance_spec_for_list_db_instances_output import InstanceSpecForListDBInstancesOutput
from volcenginesdkrdsmysql.models.instance_spec_for_modify_db_instance_input import InstanceSpecForModifyDBInstanceInput
from volcenginesdkrdsmysql.models.list_accounts_request import ListAccountsRequest
from volcenginesdkrdsmysql.models.list_accounts_response import ListAccountsResponse
from volcenginesdkrdsmysql.models.list_backups_request import ListBackupsRequest
from volcenginesdkrdsmysql.models.list_backups_response import ListBackupsResponse
from volcenginesdkrdsmysql.models.list_db_instance_ip_lists_request import ListDBInstanceIPListsRequest
from volcenginesdkrdsmysql.models.list_db_instance_ip_lists_response import ListDBInstanceIPListsResponse
from volcenginesdkrdsmysql.models.list_db_instances_request import ListDBInstancesRequest
from volcenginesdkrdsmysql.models.list_db_instances_response import ListDBInstancesResponse
from volcenginesdkrdsmysql.models.list_databases_request import ListDatabasesRequest
from volcenginesdkrdsmysql.models.list_databases_response import ListDatabasesResponse
from volcenginesdkrdsmysql.models.list_instance_params_history_request import ListInstanceParamsHistoryRequest
from volcenginesdkrdsmysql.models.list_instance_params_history_response import ListInstanceParamsHistoryResponse
from volcenginesdkrdsmysql.models.list_instance_params_request import ListInstanceParamsRequest
from volcenginesdkrdsmysql.models.list_instance_params_response import ListInstanceParamsResponse
from volcenginesdkrdsmysql.models.list_parameter_templates_request import ListParameterTemplatesRequest
from volcenginesdkrdsmysql.models.list_parameter_templates_response import ListParameterTemplatesResponse
from volcenginesdkrdsmysql.models.list_regions_request import ListRegionsRequest
from volcenginesdkrdsmysql.models.list_regions_response import ListRegionsResponse
from volcenginesdkrdsmysql.models.list_vpcs_request import ListVpcsRequest
from volcenginesdkrdsmysql.models.list_vpcs_response import ListVpcsResponse
from volcenginesdkrdsmysql.models.list_zones_request import ListZonesRequest
from volcenginesdkrdsmysql.models.list_zones_response import ListZonesResponse
from volcenginesdkrdsmysql.models.modify_allow_list_request import ModifyAllowListRequest
from volcenginesdkrdsmysql.models.modify_allow_list_response import ModifyAllowListResponse
from volcenginesdkrdsmysql.models.modify_db_instance_ip_list_request import ModifyDBInstanceIPListRequest
from volcenginesdkrdsmysql.models.modify_db_instance_ip_list_response import ModifyDBInstanceIPListResponse
from volcenginesdkrdsmysql.models.modify_db_instance_request import ModifyDBInstanceRequest
from volcenginesdkrdsmysql.models.modify_db_instance_response import ModifyDBInstanceResponse
from volcenginesdkrdsmysql.models.modify_instance_params_request import ModifyInstanceParamsRequest
from volcenginesdkrdsmysql.models.modify_instance_params_response import ModifyInstanceParamsResponse
from volcenginesdkrdsmysql.models.modify_parameter_template_request import ModifyParameterTemplateRequest
from volcenginesdkrdsmysql.models.modify_parameter_template_response import ModifyParameterTemplateResponse
from volcenginesdkrdsmysql.models.parameter_for_describe_apply_parameter_template_output import ParameterForDescribeApplyParameterTemplateOutput
from volcenginesdkrdsmysql.models.parameter_for_modify_instance_params_input import ParameterForModifyInstanceParamsInput
from volcenginesdkrdsmysql.models.recovery_db_instance_request import RecoveryDBInstanceRequest
from volcenginesdkrdsmysql.models.recovery_db_instance_response import RecoveryDBInstanceResponse
from volcenginesdkrdsmysql.models.reset_account_password_request import ResetAccountPasswordRequest
from volcenginesdkrdsmysql.models.reset_account_password_response import ResetAccountPasswordResponse
from volcenginesdkrdsmysql.models.restart_db_instance_request import RestartDBInstanceRequest
from volcenginesdkrdsmysql.models.restart_db_instance_response import RestartDBInstanceResponse
from volcenginesdkrdsmysql.models.save_as_parameter_template_request import SaveAsParameterTemplateRequest
from volcenginesdkrdsmysql.models.save_as_parameter_template_response import SaveAsParameterTemplateResponse
from volcenginesdkrdsmysql.models.template_info_for_describe_parameter_template_output import TemplateInfoForDescribeParameterTemplateOutput
from volcenginesdkrdsmysql.models.template_param_for_create_parameter_template_input import TemplateParamForCreateParameterTemplateInput
from volcenginesdkrdsmysql.models.template_param_for_describe_parameter_template_output import TemplateParamForDescribeParameterTemplateOutput
from volcenginesdkrdsmysql.models.template_param_for_list_parameter_templates_output import TemplateParamForListParameterTemplatesOutput
from volcenginesdkrdsmysql.models.template_param_for_modify_parameter_template_input import TemplateParamForModifyParameterTemplateInput
from volcenginesdkrdsmysql.models.upgrade_allow_list_version_request import UpgradeAllowListVersionRequest
from volcenginesdkrdsmysql.models.upgrade_allow_list_version_response import UpgradeAllowListVersionResponse



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeConfigForCreateNodePoolInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_container_storage_enabled': 'bool',
        'auto_renew': 'bool',
        'auto_renew_period': 'int',
        'data_volumes': 'list[DataVolumeForCreateNodePoolInput]',
        'hpc_cluster_ids': 'list[str]',
        'image_id': 'str',
        'initialize_script': 'str',
        'instance_charge_type': 'str',
        'instance_type_ids': 'list[str]',
        'name_prefix': 'str',
        'period': 'int',
        'security': 'SecurityForCreateNodePoolInput',
        'subnet_ids': 'list[str]',
        'system_volume': 'SystemVolumeForCreateNodePoolInput',
        'tags': 'list[TagForCreateNodePoolInput]'
    }

    attribute_map = {
        'additional_container_storage_enabled': 'AdditionalContainerStorageEnabled',
        'auto_renew': 'AutoRenew',
        'auto_renew_period': 'AutoRenewPeriod',
        'data_volumes': 'DataVolumes',
        'hpc_cluster_ids': 'HpcClusterIds',
        'image_id': 'ImageId',
        'initialize_script': 'InitializeScript',
        'instance_charge_type': 'InstanceChargeType',
        'instance_type_ids': 'InstanceTypeIds',
        'name_prefix': 'NamePrefix',
        'period': 'Period',
        'security': 'Security',
        'subnet_ids': 'SubnetIds',
        'system_volume': 'SystemVolume',
        'tags': 'Tags'
    }

    def __init__(self, additional_container_storage_enabled=None, auto_renew=None, auto_renew_period=None, data_volumes=None, hpc_cluster_ids=None, image_id=None, initialize_script=None, instance_charge_type=None, instance_type_ids=None, name_prefix=None, period=None, security=None, subnet_ids=None, system_volume=None, tags=None, _configuration=None):  # noqa: E501
        """NodeConfigForCreateNodePoolInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._additional_container_storage_enabled = None
        self._auto_renew = None
        self._auto_renew_period = None
        self._data_volumes = None
        self._hpc_cluster_ids = None
        self._image_id = None
        self._initialize_script = None
        self._instance_charge_type = None
        self._instance_type_ids = None
        self._name_prefix = None
        self._period = None
        self._security = None
        self._subnet_ids = None
        self._system_volume = None
        self._tags = None
        self.discriminator = None

        if additional_container_storage_enabled is not None:
            self.additional_container_storage_enabled = additional_container_storage_enabled
        if auto_renew is not None:
            self.auto_renew = auto_renew
        if auto_renew_period is not None:
            self.auto_renew_period = auto_renew_period
        if data_volumes is not None:
            self.data_volumes = data_volumes
        if hpc_cluster_ids is not None:
            self.hpc_cluster_ids = hpc_cluster_ids
        if image_id is not None:
            self.image_id = image_id
        if initialize_script is not None:
            self.initialize_script = initialize_script
        if instance_charge_type is not None:
            self.instance_charge_type = instance_charge_type
        if instance_type_ids is not None:
            self.instance_type_ids = instance_type_ids
        if name_prefix is not None:
            self.name_prefix = name_prefix
        if period is not None:
            self.period = period
        if security is not None:
            self.security = security
        if subnet_ids is not None:
            self.subnet_ids = subnet_ids
        if system_volume is not None:
            self.system_volume = system_volume
        if tags is not None:
            self.tags = tags

    @property
    def additional_container_storage_enabled(self):
        """Gets the additional_container_storage_enabled of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The additional_container_storage_enabled of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: bool
        """
        return self._additional_container_storage_enabled

    @additional_container_storage_enabled.setter
    def additional_container_storage_enabled(self, additional_container_storage_enabled):
        """Sets the additional_container_storage_enabled of this NodeConfigForCreateNodePoolInput.


        :param additional_container_storage_enabled: The additional_container_storage_enabled of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: bool
        """

        self._additional_container_storage_enabled = additional_container_storage_enabled

    @property
    def auto_renew(self):
        """Gets the auto_renew of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The auto_renew of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this NodeConfigForCreateNodePoolInput.


        :param auto_renew: The auto_renew of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def auto_renew_period(self):
        """Gets the auto_renew_period of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The auto_renew_period of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: int
        """
        return self._auto_renew_period

    @auto_renew_period.setter
    def auto_renew_period(self, auto_renew_period):
        """Sets the auto_renew_period of this NodeConfigForCreateNodePoolInput.


        :param auto_renew_period: The auto_renew_period of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: int
        """

        self._auto_renew_period = auto_renew_period

    @property
    def data_volumes(self):
        """Gets the data_volumes of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The data_volumes of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: list[DataVolumeForCreateNodePoolInput]
        """
        return self._data_volumes

    @data_volumes.setter
    def data_volumes(self, data_volumes):
        """Sets the data_volumes of this NodeConfigForCreateNodePoolInput.


        :param data_volumes: The data_volumes of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: list[DataVolumeForCreateNodePoolInput]
        """

        self._data_volumes = data_volumes

    @property
    def hpc_cluster_ids(self):
        """Gets the hpc_cluster_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The hpc_cluster_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._hpc_cluster_ids

    @hpc_cluster_ids.setter
    def hpc_cluster_ids(self, hpc_cluster_ids):
        """Sets the hpc_cluster_ids of this NodeConfigForCreateNodePoolInput.


        :param hpc_cluster_ids: The hpc_cluster_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: list[str]
        """

        self._hpc_cluster_ids = hpc_cluster_ids

    @property
    def image_id(self):
        """Gets the image_id of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The image_id of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this NodeConfigForCreateNodePoolInput.


        :param image_id: The image_id of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def initialize_script(self):
        """Gets the initialize_script of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The initialize_script of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._initialize_script

    @initialize_script.setter
    def initialize_script(self, initialize_script):
        """Sets the initialize_script of this NodeConfigForCreateNodePoolInput.


        :param initialize_script: The initialize_script of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: str
        """

        self._initialize_script = initialize_script

    @property
    def instance_charge_type(self):
        """Gets the instance_charge_type of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The instance_charge_type of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._instance_charge_type

    @instance_charge_type.setter
    def instance_charge_type(self, instance_charge_type):
        """Sets the instance_charge_type of this NodeConfigForCreateNodePoolInput.


        :param instance_charge_type: The instance_charge_type of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: str
        """
        allowed_values = ["PostPaid", "PrePaid"]  # noqa: E501
        if (self._configuration.client_side_validation and
                instance_charge_type not in allowed_values):
            raise ValueError(
                "Invalid value for `instance_charge_type` ({0}), must be one of {1}"  # noqa: E501
                .format(instance_charge_type, allowed_values)
            )

        self._instance_charge_type = instance_charge_type

    @property
    def instance_type_ids(self):
        """Gets the instance_type_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The instance_type_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._instance_type_ids

    @instance_type_ids.setter
    def instance_type_ids(self, instance_type_ids):
        """Sets the instance_type_ids of this NodeConfigForCreateNodePoolInput.


        :param instance_type_ids: The instance_type_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: list[str]
        """

        self._instance_type_ids = instance_type_ids

    @property
    def name_prefix(self):
        """Gets the name_prefix of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The name_prefix of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: str
        """
        return self._name_prefix

    @name_prefix.setter
    def name_prefix(self, name_prefix):
        """Sets the name_prefix of this NodeConfigForCreateNodePoolInput.


        :param name_prefix: The name_prefix of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: str
        """

        self._name_prefix = name_prefix

    @property
    def period(self):
        """Gets the period of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The period of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this NodeConfigForCreateNodePoolInput.


        :param period: The period of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def security(self):
        """Gets the security of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The security of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: SecurityForCreateNodePoolInput
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this NodeConfigForCreateNodePoolInput.


        :param security: The security of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: SecurityForCreateNodePoolInput
        """

        self._security = security

    @property
    def subnet_ids(self):
        """Gets the subnet_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The subnet_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """Sets the subnet_ids of this NodeConfigForCreateNodePoolInput.


        :param subnet_ids: The subnet_ids of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: list[str]
        """

        self._subnet_ids = subnet_ids

    @property
    def system_volume(self):
        """Gets the system_volume of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The system_volume of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: SystemVolumeForCreateNodePoolInput
        """
        return self._system_volume

    @system_volume.setter
    def system_volume(self, system_volume):
        """Sets the system_volume of this NodeConfigForCreateNodePoolInput.


        :param system_volume: The system_volume of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: SystemVolumeForCreateNodePoolInput
        """

        self._system_volume = system_volume

    @property
    def tags(self):
        """Gets the tags of this NodeConfigForCreateNodePoolInput.  # noqa: E501


        :return: The tags of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :rtype: list[TagForCreateNodePoolInput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this NodeConfigForCreateNodePoolInput.


        :param tags: The tags of this NodeConfigForCreateNodePoolInput.  # noqa: E501
        :type: list[TagForCreateNodePoolInput]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeConfigForCreateNodePoolInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeConfigForCreateNodePoolInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeConfigForCreateNodePoolInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeForDescribeDBInstanceDetailOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_delay_time': 'int',
        'node_id': 'str',
        'node_role': 'str',
        'node_spec': 'str',
        'node_status': 'str',
        'total_memory_gb': 'float',
        'total_storage_gb': 'float',
        'totalv_cpu': 'float',
        'used_memory_gb': 'float',
        'used_storage_gb': 'float',
        'usedv_cpu': 'float'
    }

    attribute_map = {
        'node_delay_time': 'NodeDelayTime',
        'node_id': 'NodeId',
        'node_role': 'NodeRole',
        'node_spec': 'NodeSpec',
        'node_status': 'NodeStatus',
        'total_memory_gb': 'TotalMemoryGB',
        'total_storage_gb': 'TotalStorageGB',
        'totalv_cpu': 'TotalvCPU',
        'used_memory_gb': 'UsedMemoryGB',
        'used_storage_gb': 'UsedStorageGB',
        'usedv_cpu': 'UsedvCPU'
    }

    def __init__(self, node_delay_time=None, node_id=None, node_role=None, node_spec=None, node_status=None, total_memory_gb=None, total_storage_gb=None, totalv_cpu=None, used_memory_gb=None, used_storage_gb=None, usedv_cpu=None, _configuration=None):  # noqa: E501
        """NodeForDescribeDBInstanceDetailOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._node_delay_time = None
        self._node_id = None
        self._node_role = None
        self._node_spec = None
        self._node_status = None
        self._total_memory_gb = None
        self._total_storage_gb = None
        self._totalv_cpu = None
        self._used_memory_gb = None
        self._used_storage_gb = None
        self._usedv_cpu = None
        self.discriminator = None

        if node_delay_time is not None:
            self.node_delay_time = node_delay_time
        if node_id is not None:
            self.node_id = node_id
        if node_role is not None:
            self.node_role = node_role
        if node_spec is not None:
            self.node_spec = node_spec
        if node_status is not None:
            self.node_status = node_status
        if total_memory_gb is not None:
            self.total_memory_gb = total_memory_gb
        if total_storage_gb is not None:
            self.total_storage_gb = total_storage_gb
        if totalv_cpu is not None:
            self.totalv_cpu = totalv_cpu
        if used_memory_gb is not None:
            self.used_memory_gb = used_memory_gb
        if used_storage_gb is not None:
            self.used_storage_gb = used_storage_gb
        if usedv_cpu is not None:
            self.usedv_cpu = usedv_cpu

    @property
    def node_delay_time(self):
        """Gets the node_delay_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_delay_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: int
        """
        return self._node_delay_time

    @node_delay_time.setter
    def node_delay_time(self, node_delay_time):
        """Sets the node_delay_time of this NodeForDescribeDBInstanceDetailOutput.


        :param node_delay_time: The node_delay_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: int
        """

        self._node_delay_time = node_delay_time

    @property
    def node_id(self):
        """Gets the node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this NodeForDescribeDBInstanceDetailOutput.


        :param node_id: The node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def node_role(self):
        """Gets the node_role of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_role of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_role

    @node_role.setter
    def node_role(self, node_role):
        """Sets the node_role of this NodeForDescribeDBInstanceDetailOutput.


        :param node_role: The node_role of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_role = node_role

    @property
    def node_spec(self):
        """Gets the node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_spec

    @node_spec.setter
    def node_spec(self, node_spec):
        """Sets the node_spec of this NodeForDescribeDBInstanceDetailOutput.


        :param node_spec: The node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_spec = node_spec

    @property
    def node_status(self):
        """Gets the node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_status

    @node_status.setter
    def node_status(self, node_status):
        """Sets the node_status of this NodeForDescribeDBInstanceDetailOutput.


        :param node_status: The node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_status = node_status

    @property
    def total_memory_gb(self):
        """Gets the total_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The total_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._total_memory_gb

    @total_memory_gb.setter
    def total_memory_gb(self, total_memory_gb):
        """Sets the total_memory_gb of this NodeForDescribeDBInstanceDetailOutput.


        :param total_memory_gb: The total_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._total_memory_gb = total_memory_gb

    @property
    def total_storage_gb(self):
        """Gets the total_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The total_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._total_storage_gb

    @total_storage_gb.setter
    def total_storage_gb(self, total_storage_gb):
        """Sets the total_storage_gb of this NodeForDescribeDBInstanceDetailOutput.


        :param total_storage_gb: The total_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._total_storage_gb = total_storage_gb

    @property
    def totalv_cpu(self):
        """Gets the totalv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The totalv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._totalv_cpu

    @totalv_cpu.setter
    def totalv_cpu(self, totalv_cpu):
        """Sets the totalv_cpu of this NodeForDescribeDBInstanceDetailOutput.


        :param totalv_cpu: The totalv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._totalv_cpu = totalv_cpu

    @property
    def used_memory_gb(self):
        """Gets the used_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The used_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._used_memory_gb

    @used_memory_gb.setter
    def used_memory_gb(self, used_memory_gb):
        """Sets the used_memory_gb of this NodeForDescribeDBInstanceDetailOutput.


        :param used_memory_gb: The used_memory_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._used_memory_gb = used_memory_gb

    @property
    def used_storage_gb(self):
        """Gets the used_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The used_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._used_storage_gb

    @used_storage_gb.setter
    def used_storage_gb(self, used_storage_gb):
        """Sets the used_storage_gb of this NodeForDescribeDBInstanceDetailOutput.


        :param used_storage_gb: The used_storage_gb of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._used_storage_gb = used_storage_gb

    @property
    def usedv_cpu(self):
        """Gets the usedv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The usedv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: float
        """
        return self._usedv_cpu

    @usedv_cpu.setter
    def usedv_cpu(self, usedv_cpu):
        """Sets the usedv_cpu of this NodeForDescribeDBInstanceDetailOutput.


        :param usedv_cpu: The usedv_cpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: float
        """

        self._usedv_cpu = usedv_cpu

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeForDescribeDBInstanceDetailOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeForDescribeDBInstanceDetailOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeForDescribeDBInstanceDetailOutput):
            return True

        return self.to_dict() != other.to_dict()
